@@ -11,7 +11,7 @@ import dateutil.parser
 import defusedxml.ElementTree as safe_etree
 import pytz
 
-import lxml.etree as etree
+from lxml import etree
 from openassessment.xblock.data_conversion import update_assessments_format
 from openassessment.xblock.lms_mixin import GroupAccessDict
 
